Description Details Value References Examples
iClust2 GLMNET
These data are the cross-validation elastic net fit object for only using intClust2 patients.
iclust2_glmnet |
a glmnet object |
Noah Simon, Jerome Friedman, Trevor Hastie, Rob Tibshirani (2011). Regularization Paths for Cox's Proportional Hazards Model via Coordinate Descent. Journal of Statistical Software, 39(5), 1-13. URL http://www.jstatsoft.org/v39/i05/.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.